@@ -190,12 +190,6 @@ void CFtpControlSocket::OnConnect()
 			m_pTlsSocket = new CTlsSocket(this, *socket_, this);
 			m_pBackend = m_pTlsSocket;
 
-			if (!m_pTlsSocket->Init()) {
-				LogMessage(MessageType::Error, _("Failed to initialize TLS."));
-				DoClose();
-				return;
-			}
-
 			int res = m_pTlsSocket->Handshake();
 			if (res == FZ_REPLY_ERROR) {
 				DoClose();
@@ -341,7 +335,7 @@ void CFtpControlSocket::List(CServerPath const& path, std::wstring const& subDir
 		LogMessage(MessageType::Status, _("Retrieving directory listing of \"%s\"..."), newPath.GetPath());
 	}
 
-	Push(std::make_unique<CFtpListOpData>(*this, path, subDir, flags, operations_.empty()));
+	Push(std::make_unique<CFtpListOpData>(*this, path, subDir, flags));
 }
 
 int CFtpControlSocket::ResetOperation(int nErrorCode)
