@@ -198,6 +198,7 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 				}
 				CInteractiveLoginNotification *pNotification = new CInteractiveLoginNotification(t, challenge, data.lastChallenge == challengeIdentifier);
 				pNotification->server = currentServer_;
+				pNotification->handle_ = handle_;
 				pNotification->credentials = data.credentials_;
 
 				SendAsyncRequest(pNotification);
@@ -647,14 +648,14 @@ void CSftpControlSocket::OnQuotaRequest(CRateLimiter::rate_direction direction)
 		else {
 			b = static_cast<int>(bytes);
 		}
-		AddToStream(fz::sprintf(L"-%d%d,%d\n", direction, b, engine_.GetOptions().GetOptionVal(OPTION_SPEEDLIMIT_INBOUND + static_cast<int>(direction))));
+		AddToStream(fz::sprintf("-%d%d,%d\n", direction, b, engine_.GetOptions().GetOptionVal(OPTION_SPEEDLIMIT_INBOUND + static_cast<int>(direction))));
 		UpdateUsage(direction, b);
 	}
 	else if (bytes == 0) {
 		Wait(direction);
 	}
 	else if (bytes < 0) {
-		AddToStream(fz::sprintf(L"-%d-\n", direction));
+		AddToStream(fz::sprintf("-%d-\n", direction));
 	}
 }
 
