@@ -1,6 +1,8 @@
 #ifndef FILEZILLA_ENGINE_SERVER_HEADER
 #define FILEZILLA_ENGINE_SERVER_HEADER
 
+#include <memory>
+
 enum ServerProtocol
 {
 	// Never change any existing values or user's saved sites will become
@@ -30,7 +32,11 @@ enum ServerProtocol
 
 	DROPBOX,
 
-	MAX_VALUE = DROPBOX
+	ONEDRIVE,
+
+	B2,
+
+	MAX_VALUE = B2
 };
 
 enum ServerType
@@ -84,7 +90,8 @@ enum class ProtocolFeature
 	DirectoryRename,
 	PostLoginCommands,
 	S3Lifecycle,
-	RecursiveDelete
+	RecursiveDelete,
+	ServerAssignedHome
 };
 
 class Credentials;
@@ -121,6 +128,14 @@ public:
 	bool operator<(const CServer &op) const;
 	bool operator!=(const CServer &op) const;
 
+	// Returns whether the argument refers to the same resource.
+	// Compares things like protocol and hostname, but excludes things like the name or the timezone offset.
+	bool SameResource(CServer const& other) const;
+
+	// Stricter than SameResource, also compares things like the encoding.
+	// Can be used as key comparator in content caches
+	bool SameContent(CServer const& other) const;
+
 	bool SetTimezoneOffset(int minutes);
 	void SetPasvMode(PasvMode pasvMode);
 	void MaximumMultipleConnections(int maximum);
@@ -143,6 +158,7 @@ public:
 	static std::wstring GetPrefixFromProtocol(ServerProtocol const protocol);
 	static std::vector<ServerProtocol> const& GetDefaultProtocols();
 
+	bool HasFeature(ProtocolFeature const feature) const;
 	static bool ProtocolHasFeature(ServerProtocol const protocol, ProtocolFeature const feature);
 
 	// These commands will be executed after a successful login.
@@ -266,4 +282,13 @@ protected:
 	std::map<std::string, std::wstring> extraParameters_;
 };
 
+struct ServerHandleData {
+protected:
+	ServerHandleData() = default;
+	virtual ~ServerHandleData() = default;
+	ServerHandleData(ServerHandleData const&) = default;
+	ServerHandleData& operator=(ServerHandleData const&) = default;
+};
+typedef std::weak_ptr<ServerHandleData> ServerHandle;
+
 #endif
