@@ -3,6 +3,7 @@
 
 #include "wrapengine.h"
 
+class wxGridBagSizer;
 struct DialogLayout final
 {
 public:
@@ -15,10 +16,15 @@ public:
 	static wxSizerFlags const valigng;
 
 	wxFlexGridSizer* createFlex(int cols, int rows = 0) const;
+	wxGridBagSizer* createGridBag(int cols, int rows = 0) const;
 	wxStdDialogButtonSizer* createButtonSizer(wxWindow* parent, wxSizer * sizer, bool hline) const;
 
 	DialogLayout(wxTopLevelWindow * parent);
 
+	void gbNewRow(wxGridBagSizer * gb) const;
+	wxSizerItem* gbAddRow(wxGridBagSizer * gb, wxWindow* wnd, wxSizerFlags const& flags = wxSizerFlags()) const;
+	wxSizerItem* gbAdd(wxGridBagSizer * gb, wxWindow* wnd, wxSizerFlags const& flags = wxSizerFlags()) const;
+
 protected:
 	wxTopLevelWindow * parent_;
 };
@@ -56,4 +62,6 @@ protected:
 	std::unique_ptr<DialogLayout> layout_;
 };
 
+std::wstring LabelEscape(std::wstring const& label);
+
 #endif
