@@ -122,7 +122,7 @@ protected:
 private:
 	virtual bool CanStartComparison() { return false; }
 	virtual void StartComparison() {}
-	virtual bool get_next_file(wxString&, bool &, int64_t&, fz::datetime&) { return false; }
+	virtual bool get_next_file(std::wstring &, bool &, int64_t&, fz::datetime&) override { return false; }
 	virtual void CompareAddFile(CComparableListing::t_fileEntryFlags) {}
 	virtual void FinishComparison() {}
 	virtual void ScrollTopItem(int) {}
@@ -518,7 +518,7 @@ void CSearchDialog::Run()
 	}
 }
 
-void CSearchDialog::OnStateChange(t_statechange_notifications notification, const wxString&, const void* data2)
+void CSearchDialog::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void* data2)
 {
 	if (notification == STATECHANGE_REMOTE_DIR_OTHER && data2) {
 		if (m_searching == search_mode::remote) {
@@ -567,18 +567,18 @@ void CSearchDialog::ProcessDirectoryListing(std::shared_ptr<CDirectoryListing> c
 	int old_count = m_results->m_fileData.size();
 	int added_count = 0;
 
-	wxString const path = listing->path.GetPath();
+	std::wstring const path = listing->path.GetPath();
 
 	bool const has_selections = m_results->GetSelectedItemCount() != 0;
 
 	std::vector<int> added_indexes;
 	if (has_selections) {
-		added_indexes.reserve(listing->GetCount());
+		added_indexes.reserve(listing->size());
 	}
 
 	std::unique_ptr<CFileListCtrlSortBase> compare = m_results->GetSortComparisonObject();
-	for (unsigned int i = 0; i < listing->GetCount(); ++i) {
-		const CDirentry& entry = (*listing)[i];
+	for (size_t i = 0; i < listing->size(); ++i) {
+		CDirentry const& entry = (*listing)[i];
 
 		if (!CFilterManager::FilenameFilteredByFilter(m_search_filter, entry.name, path, entry.is_dir(), entry.size, 0, entry.time)) {
 			continue;
@@ -626,7 +626,7 @@ void CSearchDialog::ProcessDirectoryListing(CLocalRecursiveOperation::listing co
 	int old_count = m_results->m_fileData.size();
 	int added_count = 0;
 
-	wxString const path = listing.localPath.GetPath();
+	std::wstring const path = listing.localPath.GetPath();
 
 	bool const has_selections = m_results->GetSelectedItemCount() != 0;
 
@@ -717,14 +717,15 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 			return;
 		}
 
-		CServerPath path;
 
-		ServerWithCredentials const& server = m_state.GetServer();
-		if (!server) {
+		Site const& site = m_state.GetSite();
+		if (!site) {
 			wxMessageBoxEx(_("Connection to server lost."), _("Remote file search"), wxICON_EXCLAMATION);
 			return;
 		}
-		path.SetType(server.server.GetType());
+
+		CServerPath path;
+		path.SetType(site.server.GetType());
 		if (!path.SetPath(xrc_call(*this, "ID_PATH", &wxTextCtrl::GetValue).ToStdWstring()) || path.empty()) {
 			wxMessageBoxEx(_("Need to enter valid remote path"), _("Remote file search"), wxICON_EXCLAMATION);
 			return;
@@ -739,12 +740,9 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 		wxMessageBoxEx(wxString::Format(_("Invalid search conditions: %s"), error), _("File search"), wxICON_EXCLAMATION);
 		return;
 	}
-	m_search_filter = GetFilter();
-	if (!CFilterManager::CompileRegexes(m_search_filter)) {
-		wxMessageBoxEx(_("Invalid regular expression in search conditions."), _("File search"), wxICON_EXCLAMATION);
-		return;
-	}
-	m_search_filter.matchCase = xrc_call(*this, "ID_CASE", &wxCheckBox::GetValue);
+	bool const matchCase = xrc_call(*this, "ID_CASE", &wxCheckBox::GetValue);
+	m_search_filter = GetFilter(matchCase);
+	m_search_filter.matchCase = matchCase;
 	m_search_filter.filterFiles = xrc_call(*this, "ID_FIND_FILES", &wxCheckBox::GetValue);
 	m_search_filter.filterDirs = xrc_call(*this, "ID_FIND_DIRS", &wxCheckBox::GetValue);
 
@@ -828,6 +826,7 @@ void CSearchDialog::OnContextMenu(wxContextMenuEvent& event)
 		menu.Append(XRCID("ID_MENU_SEARCH_UPLOAD"), _("&Upload..."));
 		menu.Append(XRCID("ID_MENU_SEARCH_OPEN"), _("O&pen"));
 		menu.Append(XRCID("ID_MENU_SEARCH_FILEMANAGER"), _("Show in file &manager"));
+		menu.Append(XRCID("ID_MENU_SEARCH_DELETE"), _("D&elete"));
 
 		menu.Enable(XRCID("ID_MENU_SEARCH_UPLOAD"), connected);
 	}
@@ -864,17 +863,17 @@ public:
 			return false;
 		}
 
-		wxString desc;
+		std::wstring desc;
 		if (!count_dirs) {
-			desc.Printf(wxPLURAL("Selected %d file for transfer.", "Selected %d files for transfer.", count_files), count_files);
+			desc = fz::sprintf(fztranslate("Selected %d file for transfer.", "Selected %d files for transfer.", count_files), count_files);
 		}
 		else if (!count_files) {
-			desc.Printf(wxPLURAL("Selected %d directory with its contents for transfer.", "Selected %d directories with their contents for transfer.", count_dirs), count_dirs);
+			desc = fz::sprintf(fztranslate("Selected %d directory with its contents for transfer.", "Selected %d directories with their contents for transfer.", count_dirs), count_dirs);
 		}
 		else {
-			wxString files = wxString::Format(wxPLURAL("%d file", "%d files", count_files), count_files);
-			wxString dirs = wxString::Format(wxPLURAL("%d directory with its contents", "%d directories with their contents", count_dirs), count_dirs);
-			desc.Printf(_("Selected %s and %s for transfer."), files, dirs);
+			std::wstring files = fz::sprintf(fztranslate("%d file", "%d files", count_files), count_files);
+			std::wstring dirs = fz::sprintf(fztranslate("%d directory with its contents", "%d directories with their contents", count_dirs), count_dirs);
+			desc = fz::sprintf(fztranslate("Selected %s and %s for transfer."), files, dirs);
 		}
 		XRCCTRL(*this, "ID_DESC", wxStaticText)->SetLabel(desc);
 
@@ -1043,8 +1042,8 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 		return;
 	}
 
-	ServerWithCredentials const& server = m_state.GetServer();
-	if (!server) {
+	Site const& site = m_state.GetSite();
+	if (!site) {
 		wxBell();
 		return;
 	}
@@ -1076,7 +1075,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 
 		m_pQueue->QueueFile(!start, true,
 			entry.name, (localName != entry.name) ? localName : std::wstring(),
-			target_path, remote_path, server, entry.size);
+			target_path, remote_path, site, entry.size);
 	}
 	m_pQueue->QueueFile_Finish(start);
 
@@ -1124,8 +1123,8 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 		return;
 	}
 
-	ServerWithCredentials const& server = m_state.GetServer();
-	if (!server) {
+	Site const& site = m_state.GetSite();
+	if (!site) {
 		wxBell();
 		return;
 	}
@@ -1155,7 +1154,7 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 
 		m_pQueue->QueueFile(!start, false,
 			entry.name, (localName != entry.name) ? localName : std::wstring(),
-			local_path, target_path, server, entry.size);
+			local_path, target_path, site, entry.size);
 	}
 	m_pQueue->QueueFile_Finish(start);
 
@@ -1211,8 +1210,8 @@ void CSearchDialog::OnEdit(wxCommandEvent&)
 		return;
 	}
 
-	ServerWithCredentials const& server = m_state.GetServer();
-	if (!server) {
+	Site const& site = m_state.GetSite();
+	if (!site) {
 		wxBell();
 		return;
 	}
@@ -1231,7 +1230,7 @@ void CSearchDialog::OnEdit(wxCommandEvent&)
 		const CDirentry& entry = m_results->remoteFileData_[item];
 		const CServerPath path = m_results->remoteFileData_[item].path;
 
-		pEditHandler->Edit(CEditHandler::remote, entry.name, path, server, entry.size, this);
+		pEditHandler->Edit(CEditHandler::remote, entry.name, path, site, entry.size, this);
 	}
 }
 
@@ -1251,17 +1250,18 @@ void CSearchDialog::OnDelete(wxCommandEvent&)
 			return;
 		}
 
-		wxString question;
+		
+		std::wstring question;
 		if (selected_dirs.empty()) {
-			question.Printf(wxPLURAL("Really delete %d file from the server?", "Really delete %d files from the server?", selected_files.size()), selected_files.size());
+			question = fz::sprintf(fztranslate("Really delete %d file from the server?", "Really delete %d files from the server?", selected_files.size()), selected_files.size());
 		}
 		else if (selected_files.empty()) {
-			question.Printf(wxPLURAL("Really delete %d directory with its contents from the server?", "Really delete %d directories with their contents from the server?", selected_dirs.size()), selected_dirs.size());
+			question = fz::sprintf(fztranslate("Really delete %d directory with its contents from the server?", "Really delete %d directories with their contents from the server?", selected_dirs.size()), selected_dirs.size());
 		}
 		else {
-			wxString files = wxString::Format(wxPLURAL("%d file", "%d files", selected_files.size()), selected_files.size());
-			wxString dirs = wxString::Format(wxPLURAL("%d directory with its contents", "%d directories with their contents", selected_dirs.size()), selected_dirs.size());
-			question.Printf(_("Really delete %s and %s from the server?"), files, dirs);
+			std::wstring files = fz::sprintf(fztranslate("%d file", "%d files", selected_files.size()), selected_files.size());
+			std::wstring dirs = fz::sprintf(fztranslate("%d directory with its contents", "%d directories with their contents", selected_dirs.size()), selected_dirs.size());
+			question = fz::sprintf(fztranslate("Really delete %s and %s from the server?"), files, dirs);
 		}
 
 		if (wxMessageBoxEx(question, _("Confirm deletion"), wxICON_QUESTION | wxYES_NO) != wxYES) {
@@ -1409,8 +1409,8 @@ void CSearchDialog::OnGetUrl(wxCommandEvent& event)
 		return;
 	}
 
-	ServerWithCredentials const& server = m_state.GetServer();
-	if (!server) {
+	Site const& site = m_state.GetSite();
+	if (!site) {
 		wxBell();
 		return;
 	}
@@ -1420,10 +1420,10 @@ void CSearchDialog::OnGetUrl(wxCommandEvent& event)
 		return;
 	}
 
-	wxString const url = server.Format((event.GetId() == XRCID("ID_MENU_SEARCH_GETURL_PASSWORD")) ? ServerFormat::url_with_password : ServerFormat::url);
+	std::wstring const url = site.Format((event.GetId() == XRCID("ID_MENU_SEARCH_GETURL_PASSWORD")) ? ServerFormat::url_with_password : ServerFormat::url);
 
-	auto getUrl = [](wxString const& serverPart, CServerPath const& path, std::wstring const& name) {
-		wxString url = serverPart;
+	auto getUrl = [](std::wstring const& serverPart, CServerPath const& path, std::wstring const& name) {
+		std::wstring url = serverPart;
 
 		auto const pathPart = fz::percent_encode_w(path.FormatFilename(name, false), true);
 		if (!pathPart.empty() && pathPart[0] != '/') {
@@ -1434,7 +1434,7 @@ void CSearchDialog::OnGetUrl(wxCommandEvent& event)
 		return url;
 	};
 
-	wxString urls;
+	std::wstring urls;
 
 	int sel = -1;
 	while ((sel = m_results->GetNextItem(sel, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) >= 0) {
@@ -1446,9 +1446,9 @@ void CSearchDialog::OnGetUrl(wxCommandEvent& event)
 		auto const& entry = m_results->remoteFileData_[index];
 		urls += getUrl(url, entry.path, entry.name);
 #ifdef __WXMSW__
-		urls += _T("\r\n");
+		urls += L"\r\n";
 #else
-		urls += _T("\n");
+		urls += L"\n";
 #endif
 	}
 
