@@ -505,7 +505,7 @@ void CLocalViewHeader::OnTextEnter(wxCommandEvent&)
 	}
 }
 
-void CLocalViewHeader::OnStateChange(t_statechange_notifications notification, const wxString&, const void*)
+void CLocalViewHeader::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void*)
 {
 	if (notification == STATECHANGE_SERVER) {
 		m_windowTinter->SetBackgroundTint(m_state.GetSite().m_colour);
@@ -533,7 +533,7 @@ CRemoteViewHeader::CRemoteViewHeader(wxWindow* pParent, CState& state)
 	Disable();
 }
 
-void CRemoteViewHeader::OnStateChange(t_statechange_notifications notification, const wxString&, const void*)
+void CRemoteViewHeader::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void*)
 {
 	if (notification == STATECHANGE_SERVER) {
 		m_windowTinter->SetBackgroundTint(m_state.GetSite().m_colour);
@@ -545,12 +545,12 @@ void CRemoteViewHeader::OnStateChange(t_statechange_notifications notification,
 			Disable();
 		}
 		else {
-			ServerWithCredentials const& server = m_state.GetServer();
-			if (server && server.server != m_lastServer) {
+			Site const& site = m_state.GetSite();
+			if (site && site.server != m_lastServer) {
 				m_pComboBox->Clear();
 				m_recentDirectories.clear();
 				m_sortedRecentDirectories.clear();
-				m_lastServer = server.server;
+				m_lastServer = site.server;
 			}
 			Enable();
 #ifdef __WXGTK__
